﻿import-module C:\Chocolatey\chocolateyInstall\helpers\chocolateyInstaller

$gae_version = '1.6.6'

function Get-Input() {
 $res = $null
 $flags = 'p', 'j', 'b', 'n'
 
  do {
     $res = Read-Host "Select Google App Engine(GAE) installation option: 
     - for Python, type p
     - for Java, type j
     - both Python/Java, type b
     - No, Thanks! type n"
      
     if ($res -eq $null) {
       $res = 'n'
     }
     
     $res = $res.ToLower()     
  }
  while ($flags -notcontains $res)

  return $res
}

function get-binRoot() {
  $binRoot = if ($env:chocolatey_bin_root -ne $null) { $env:chocolatey_bin_root } else { 'bin' }
  return Join-Path $env:systemdrive $binRoot
}

function install-gae-python() {
  try {
    $version = $gae_version
    $url = "http://googleappengine.googlecode.com/files/GoogleAppEngine-$version.msi"
    Write-Host "Installing GAE for Python"
    Install-ChocolateyPackage 'gae.python.sdk' 'msi' '/quiet' $url  -validExitCodes @(0)
    # verify => %PROGRAMFILES%\Google\google_appengine\launcher\GoogleAppEngineLauncher.exe
	Write-ChocolateySuccess 'gae.python.sdk'	
  } catch {
    Write-ChocolateyFailure 'gae.python.sdk' "$($_.Exception.Message)"
    throw 
  }
}

function install-gae-java() {
  try {
    $version = $gae_version
    $name = "appengine-java-sdk-$version"
    $url = "http://googleappengine.googlecode.com/files/$name.zip"
    $binRoot = get-binRoot  
    $gae_java_home = Join-Path $binRoot $name
  
	Write-Host "Installing GAE for Java"
    Install-ChocolateyZipPackage 'gae.java.sdk' $url $binRoot
    Install-ChocolateyPath (Join-Path $gae_java_home 'bin') 'User'
    
	Write-ChocolateySuccess 'gae.java.sdk'
  } catch {
    Write-ChocolateyFailure 'gae.java.sdk' "$($_.Exception.Message)"
    throw 
  }
}

function chocolatey-install() {
  $input = Get-Input
    
  if (('p', 'b') -contains $input) {
    install-gae-python
  }    

  if (('j', 'b') -contains $input) {
    install-gae-java
  }
}

chocolatey-install

